Struct bevy_rrise::emitter_listener::RrEmitterBundle
source · [−]pub struct RrEmitterBundle {
pub rr: RrEmitter,
pub global_tfm: GlobalTransform,
}Expand description
Static sound emitter. More optimized if you know it won’t move.
If you attach a Transform to an entity created with RrEmitterBundle, it will behave like a RrDynamicEmitterBundle.
Fields
rr: RrEmitterglobal_tfm: GlobalTransformImplementations
sourceimpl RrEmitterBundle
impl RrEmitterBundle
sourcepub fn with_rotation(self, rotation: Quat) -> Self
pub fn with_rotation(self, rotation: Quat) -> Self
Sets the rotation of this emitter.
sourcepub fn with_event<T: Into<AkID<'static>>>(
self,
event: T,
despawn_on_silent: bool
) -> Self
pub fn with_event<T: Into<AkID<'static>>>(
self,
event: T,
despawn_on_silent: bool
) -> Self
Sets the event to associate with this emitter and registers it for auto play.
If despawn_on_silent is true, despawn this emitter once it has finished playing all its
events.
sourcepub fn with_flags(self, flags: AkCallbackType) -> Self
pub fn with_flags(self, flags: AkCallbackType) -> Self
Sets the callback flags to associate with this emitter.