pub struct RrisePluginSettings {
    pub init_language: String,
    pub banks_location: PathBuf,
    pub spawn_default_listener: bool,
}
Plugin settings

Fields

init_language: String

One of the languages supported by your Wwise project in Project > Languages.

Defaults to English(US).

banks_location: PathBuf

Generated soundbanks location, relative to the Bevy asset server folder. If the path given is absolute, overrides the asset server folder by that one.

Don’t add the platform folder; just the root where to expect to find the Windows or Linux folder containing the banks.

spawn_default_listener: bool

Whether to create a default listener automatically.

If this is true, it is available after RriseLabel::RriseReady.

You can query it with Query<&RrListener, Added<RrListener>> if you want to attach it to your camera or avatar for instance.

use bevy::prelude::*;
use bevy::render::camera::Camera3d;
use bevy_rrise::emitter_listener::RrListener;
fn attach_default_listeners_to_camera(
    mut cmds: Commands,
    listeners: Query<(Entity, &RrListener), Added<RrListener>>,
    main_camera: Query<Entity, With<Camera3d>>,
) {
    let main_camera = main_camera.single();
    for (entity, listener) in listeners.iter() {
        cmds.entity(main_camera).add_child(entity);
    }
}