#[repr(transparent)]
pub struct AkCallbackType(pub i32);
Type of callback. Used as a bitfield in methods AK::SoundEngine::PostEvent() and AK::SoundEngine::DynamicSequence::Open().

Tuple Fields

0: i32

Implementations

Checks whether this bitflag has at least one of the bits in flags set.

Callback triggered when reaching the end of an event. AkCallbackInfo can be cast to AkEventCallbackInfo.

Callback triggered when reaching the end of a dynamic sequence item. AkCallbackInfo can be cast to AkDynamicSequenceItemCallbackInfo.

Callback triggered when encountering a marker during playback. AkCallbackInfo can be cast to AkMarkerCallbackInfo.

Callback triggered when the duration of the sound is known by the sound engine. AkCallbackInfo can be cast to AkDurationCallbackInfo.

Callback triggered at each frame, letting the client modify the speaker volume matrix. AkCallbackInfo can be cast to AkSpeakerVolumeMatrixCallbackInfo.

Callback triggered when playback skips a frame due to stream starvation. AkCallbackInfo can be cast to AkEventCallbackInfo.

Callback triggered when music playlist container must select the next item to play. AkCallbackInfo can be cast to AkMusicPlaylistCallbackInfo.

Callback triggered when a “Play” or “Seek” command has been executed (“Seek” commands are issued from AK::SoundEngine::SeekOnEvent()). Applies to objects of the Interactive-Music Hierarchy only. AkCallbackInfo can be cast to AkEventCallbackInfo.

Enable notifications on Music Beat. AkCallbackInfo can be cast to AkMusicSyncCallbackInfo.

Enable notifications on Music Bar. AkCallbackInfo can be cast to AkMusicSyncCallbackInfo.

Enable notifications on Music Entry Cue. AkCallbackInfo can be cast to AkMusicSyncCallbackInfo.

Enable notifications on Music Exit Cue. AkCallbackInfo can be cast to AkMusicSyncCallbackInfo.

Enable notifications on Music Grid. AkCallbackInfo can be cast to AkMusicSyncCallbackInfo.

Enable notifications on Music Custom Cue. AkCallbackInfo can be cast to AkMusicSyncCallbackInfo.

Enable notifications on Music switch transition synchronization point. AkCallbackInfo can be cast to AkMusicSyncCallbackInfo.

Use this flag if you want to receive all notifications concerning AK_MusicSync registration.

Enable notifications for MIDI events. AkCallbackInfo can be cast to AkMIDIEventCallbackInfo.

Bitmask for all callback types.

Enable play position information for use by AK::SoundEngine::GetSourcePlayPosition().

Enable play position information of music objects, queried via AK::MusicEngine::GetPlayingSegmentInfo().

Enable stream buffering information for use by AK::SoundEngine::GetSourceStreamBuffering().