pub struct PostEventAtLocation<'a> { /* private fields */ }
Helper struct to post events in a fire & forget fashion

Implementations

Selects an event by name or by ID, to play at a given location

Add flags before posting. Bitmask: see AkCallbackType.

Set flags before posting. Bitmask: see AkCallbackType

Posts the event to the sound engine.

Provide a clone of the [Res<CallbackChannel>] resource if you want to receive callbacks from Wwise (see Self::flags(), Self::add_flags()).