Struct bevy_rrise::plugin::RrisePluginSettings
source · [−]pub struct RrisePluginSettings {
pub init_language: String,
pub banks_location: PathBuf,
pub spawn_default_listener: bool,
}Expand description
Plugin settings
Fields
init_language: StringOne of the languages supported by your Wwise project in Project > Languages.
Defaults to English(US).
banks_location: PathBufGenerated soundbanks location, relative to the Bevy asset server folder. If the path given is absolute, overrides the asset server folder by that one.
Don’t add the platform folder; just the root where to expect to find the Windows or Linux folder containing the banks.
spawn_default_listener: boolWhether to create a default listener automatically.
If this is true, it is available after RriseLabel::RriseReady.
You can query it with Query<&RrListener, Added<RrListener>> if you want to attach it to
your camera or avatar for instance.
use bevy::prelude::*;
use bevy::render::camera::Camera3d;
use bevy_rrise::emitter_listener::RrListener;
fn attach_default_listeners_to_camera(
mut cmds: Commands,
listeners: Query<(Entity, &RrListener), Added<RrListener>>,
main_camera: Query<Entity, With<Camera3d>>,
) {
let main_camera = main_camera.single();
for (entity, listener) in listeners.iter() {
cmds.entity(main_camera).add_child(entity);
}
}Trait Implementations
sourceimpl Clone for RrisePluginSettings
impl Clone for RrisePluginSettings
sourcefn clone(&self) -> RrisePluginSettings
fn clone(&self) -> RrisePluginSettings
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for RrisePluginSettings
impl Debug for RrisePluginSettings
sourceimpl Default for RrisePluginSettings
impl Default for RrisePluginSettings