Struct bevy_rrise::sound_engine::AkCallbackType
[−]#[repr(transparent)]pub struct AkCallbackType(pub i32);Expand description
Type of callback. Used as a bitfield in methods AK::SoundEngine::PostEvent() and AK::SoundEngine::DynamicSequence::Open().
Tuple Fields
0: i32Implementations
impl AkCallbackType
impl AkCallbackType
pub fn contains(self, flags: AkCallbackType) -> bool
pub fn contains(self, flags: AkCallbackType) -> bool
Checks whether this bitflag has at least one of the bits in flags set.
impl AkCallbackType
impl AkCallbackType
pub const AK_EndOfEvent: AkCallbackType
pub const AK_EndOfEvent: AkCallbackType
Callback triggered when reaching the end of an event. AkCallbackInfo can be cast to AkEventCallbackInfo.
impl AkCallbackType
impl AkCallbackType
pub const AK_EndOfDynamicSequenceItem: AkCallbackType
pub const AK_EndOfDynamicSequenceItem: AkCallbackType
Callback triggered when reaching the end of a dynamic sequence item. AkCallbackInfo can be cast to AkDynamicSequenceItemCallbackInfo.
impl AkCallbackType
impl AkCallbackType
pub const AK_Marker: AkCallbackType
pub const AK_Marker: AkCallbackType
Callback triggered when encountering a marker during playback. AkCallbackInfo can be cast to AkMarkerCallbackInfo.
impl AkCallbackType
impl AkCallbackType
pub const AK_Duration: AkCallbackType
pub const AK_Duration: AkCallbackType
Callback triggered when the duration of the sound is known by the sound engine. AkCallbackInfo can be cast to AkDurationCallbackInfo.
impl AkCallbackType
impl AkCallbackType
pub const AK_SpeakerVolumeMatrix: AkCallbackType
pub const AK_SpeakerVolumeMatrix: AkCallbackType
Callback triggered at each frame, letting the client modify the speaker volume matrix. AkCallbackInfo can be cast to AkSpeakerVolumeMatrixCallbackInfo.
impl AkCallbackType
impl AkCallbackType
pub const AK_Starvation: AkCallbackType
pub const AK_Starvation: AkCallbackType
Callback triggered when playback skips a frame due to stream starvation. AkCallbackInfo can be cast to AkEventCallbackInfo.
impl AkCallbackType
impl AkCallbackType
pub const AK_MusicPlaylistSelect: AkCallbackType
pub const AK_MusicPlaylistSelect: AkCallbackType
Callback triggered when music playlist container must select the next item to play. AkCallbackInfo can be cast to AkMusicPlaylistCallbackInfo.
impl AkCallbackType
impl AkCallbackType
pub const AK_MusicPlayStarted: AkCallbackType
pub const AK_MusicPlayStarted: AkCallbackType
Callback triggered when a “Play” or “Seek” command has been executed (“Seek” commands are issued from AK::SoundEngine::SeekOnEvent()). Applies to objects of the Interactive-Music Hierarchy only. AkCallbackInfo can be cast to AkEventCallbackInfo.
impl AkCallbackType
impl AkCallbackType
pub const AK_MusicSyncBeat: AkCallbackType
pub const AK_MusicSyncBeat: AkCallbackType
Enable notifications on Music Beat. AkCallbackInfo can be cast to AkMusicSyncCallbackInfo.
impl AkCallbackType
impl AkCallbackType
pub const AK_MusicSyncBar: AkCallbackType
pub const AK_MusicSyncBar: AkCallbackType
Enable notifications on Music Bar. AkCallbackInfo can be cast to AkMusicSyncCallbackInfo.
impl AkCallbackType
impl AkCallbackType
pub const AK_MusicSyncEntry: AkCallbackType
pub const AK_MusicSyncEntry: AkCallbackType
Enable notifications on Music Entry Cue. AkCallbackInfo can be cast to AkMusicSyncCallbackInfo.
impl AkCallbackType
impl AkCallbackType
pub const AK_MusicSyncExit: AkCallbackType
pub const AK_MusicSyncExit: AkCallbackType
Enable notifications on Music Exit Cue. AkCallbackInfo can be cast to AkMusicSyncCallbackInfo.
impl AkCallbackType
impl AkCallbackType
pub const AK_MusicSyncGrid: AkCallbackType
pub const AK_MusicSyncGrid: AkCallbackType
Enable notifications on Music Grid. AkCallbackInfo can be cast to AkMusicSyncCallbackInfo.
impl AkCallbackType
impl AkCallbackType
pub const AK_MusicSyncUserCue: AkCallbackType
pub const AK_MusicSyncUserCue: AkCallbackType
Enable notifications on Music Custom Cue. AkCallbackInfo can be cast to AkMusicSyncCallbackInfo.
impl AkCallbackType
impl AkCallbackType
pub const AK_MusicSyncPoint: AkCallbackType
pub const AK_MusicSyncPoint: AkCallbackType
Enable notifications on Music switch transition synchronization point. AkCallbackInfo can be cast to AkMusicSyncCallbackInfo.
impl AkCallbackType
impl AkCallbackType
pub const AK_MusicSyncAll: AkCallbackType
pub const AK_MusicSyncAll: AkCallbackType
Use this flag if you want to receive all notifications concerning AK_MusicSync registration.
impl AkCallbackType
impl AkCallbackType
pub const AK_MIDIEvent: AkCallbackType
pub const AK_MIDIEvent: AkCallbackType
Enable notifications for MIDI events. AkCallbackInfo can be cast to AkMIDIEventCallbackInfo.
impl AkCallbackType
impl AkCallbackType
pub const AK_CallbackBits: AkCallbackType
pub const AK_CallbackBits: AkCallbackType
Bitmask for all callback types.
impl AkCallbackType
impl AkCallbackType
pub const AK_EnableGetSourcePlayPosition: AkCallbackType
pub const AK_EnableGetSourcePlayPosition: AkCallbackType
Enable play position information for use by AK::SoundEngine::GetSourcePlayPosition().
impl AkCallbackType
impl AkCallbackType
pub const AK_EnableGetMusicPlayPosition: AkCallbackType
pub const AK_EnableGetMusicPlayPosition: AkCallbackType
Enable play position information of music objects, queried via AK::MusicEngine::GetPlayingSegmentInfo().
impl AkCallbackType
impl AkCallbackType
pub const AK_EnableGetSourceStreamBuffering: AkCallbackType
pub const AK_EnableGetSourceStreamBuffering: AkCallbackType
Enable stream buffering information for use by AK::SoundEngine::GetSourceStreamBuffering().